@@ -2,7 +2,6 @@ from io import StringIO
 
 from celery.task import task
 
-from django.db import transaction
 from django.utils import timezone
 from django.utils.module_loading import import_string
 
@@ -21,15 +20,14 @@ def csv_import(task_id):  # pragma: no cover
     task_obj.save()
 
     try:
-        with transaction.atomic():
-            model = import_string(task_obj.model_class)
-            records = model.import_csv(task_obj, log)
-            task_obj.task_status = ImportTask.SUCCESS
-            task_obj.save()
+        model = import_string(task_obj.model_class)
+        records = model.import_csv(task_obj, log)
+        task_obj.task_status = ImportTask.SUCCESS
+        task_obj.save()
 
-            task_obj.log(log.getvalue())
-            task_obj.log("Import finished at %s" % timezone.now())
-            task_obj.log("%d record(s) added." % len(records))
+        task_obj.log(log.getvalue())
+        task_obj.log("Import finished at %s" % timezone.now())
+        task_obj.log("%d record(s) added." % len(records))
 
     except Exception as e:
         import traceback
